Returns the SHA256 digest of a file as a lowercase hex string, using the digest package. Used to record and verify data provenance.
Returns the SHA256 digest of a file as a lowercase hex string, using the digest package. Used to record and verify data provenance.